@@ -4,7 +4,7 @@ import requests
 from distutils.version import LooseVersion
 from redmine.version import __version__
 from redmine.managers import ResourceManager
-from redmine.utilities import to_string, json_response
+from redmine.utilities import is_string, to_string, json_response
 from redmine.exceptions import (
     AuthError,
     ConflictError,
@@ -16,7 +16,8 @@ from redmine.exceptions import (
     VersionMismatchError,
     ResourceNotFoundError,
     RequestEntityTooLargeError,
-    UnknownError
+    UnknownError,
+    ForbiddenError
 )
 
 
@@ -37,6 +38,9 @@ class Redmine(object):
 
     def __getattr__(self, resource):
         """Returns either ResourceSet or Resource object depending on the method used on the ResourceManager"""
+        if resource.startswith('_'):
+            raise AttributeError
+
         return ResourceManager(self, resource)
 
     def upload(self, filepath):
@@ -120,6 +124,8 @@ class Redmine(object):
                 return json_response(response.json)
         elif response.status_code == 401:
             raise AuthError
+        elif response.status_code == 403:
+            raise ForbiddenError
         elif response.status_code == 404:
             raise ResourceNotFoundError
         elif response.status_code == 409:
@@ -129,7 +135,8 @@ class Redmine(object):
         elif response.status_code == 413:
             raise RequestEntityTooLargeError
         elif response.status_code == 422:
-            raise ValidationError(to_string(', '.join(json_response(response.json)['errors'])))
+            errors = json_response(response.json)['errors']
+            raise ValidationError(to_string(', '.join(e if is_string(e) else ': '.join(e) for e in errors)))
         elif response.status_code == 500:
             raise ServerError
 
